documentFactory.FtpDocumentStream

|  | ## Cheshire3 Object Model: Class FtpDocumentStream

Module documentFactory :: Class FtpDocumentStream

## Class FtpDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
      RemoteDocumentStream --+
                             |
    BaseDocumentStream --+   |
                         |   |
    MultipleDocumentStream --+
                             |
                            FtpDocumentStream

Instance Methods

open_stream(self, path)
_fetchStream(self, item)
_fetchName(self, item)
_descend(self, session, dirname, cache=0)
find_documents(self, session, cache=0)
Inherited from `RemoteDocumentStream`: `parse_url` Inherited from `BaseDocumentStream`: `__init__`, `fetch_document` Inherited from `MultipleDocumentStream` (private): `_processFile`, `_processFiles`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, path) | source code
Overrides: BaseDocumentStream.open_stream

### _fetchStream(self, item) | source code
Overrides: MultipleDocumentStream._fetchStream

### _fetchName(self, item) | source code
Overrides: MultipleDocumentStream._fetchName

### _descend(self, session, dirname, cache=0) | source code

### find_documents(self, session, cache=0) | source code